@@ -3,13 +3,17 @@
 
 """Defines the ModelAnalysis class."""
 
-from responsibleai._managers.causal_manager import CausalManager
-from responsibleai._managers.counterfactual_manager import (
-    CounterfactualManager)
-from responsibleai._managers.error_analysis_manager import ErrorAnalysisManager
-from responsibleai._managers.explainer_manager import ExplainerManager
-from responsibleai.rai_insights import RAIInsights
 import warnings
+from typing import Any, List, Optional
+
+import numpy as np
+import pandas as pd
+
+from responsibleai.managers.causal_manager import CausalManager
+from responsibleai.managers.counterfactual_manager import CounterfactualManager
+from responsibleai.managers.error_analysis_manager import ErrorAnalysisManager
+from responsibleai.managers.explainer_manager import ExplainerManager
+from responsibleai.rai_insights import RAIInsights
 
 
 class ModelAnalysis(object):
@@ -18,39 +22,16 @@ class ModelAnalysis(object):
     Use ModelAnalysis to analyze errors, explain the most important
     features, compute counterfactuals and run causal analysis in a
     single API.
-    :param model: The model to compute RAI insights for.
-        A model that implements sklearn.predict or sklearn.predict_proba
-        or function that accepts a 2d ndarray.
-    :type model: object
-    :param train: The training dataset including the label column.
-    :type train: pandas.DataFrame
-    :param test: The test dataset including the label column.
-    :type test: pandas.DataFrame
-    :param target_column: The name of the label column.
-    :type target_column: str
-    :param task_type: The task to run, can be `classification` or
-        `regression`.
-    :type task_type: str
-    :param categorical_features: The categorical feature names.
-    :type categorical_features: list[str]
-    :param train_labels: The class labels in the training dataset
-    :type train_labels: ndarray
-    :param serializer: Picklable custom serializer with save and load
-        methods for custom model serialization.
-        The save method writes the model to file given a parent directory.
-        The load method returns the deserialized model from the same
-        parent directory.
-    :type serializer: object
     """
 
-    def __init__(self, model, train, test, target_column,
-                 task_type, categorical_features=None, train_labels=None,
-                 serializer=None,
+    def __init__(self, model: Any, train: pd.DataFrame, test: pd.DataFrame,
+                 target_column: str, task_type: str,
+                 categorical_features: Optional[List[str]] = None,
+                 train_labels: Optional[np.ndarray] = None,
+                 serializer: Optional[Any] = None,
                  maximum_rows_for_test: int = 5000):
-        """Defines the top-level Model Analysis API.
-        Use ModelAnalysis to analyze errors, explain the most important
-        features, compute counterfactuals and run causal analysis in a
-        single API.
+        """Creates a ModelAnalysis object.
+
         :param model: The model to compute RAI insights for.
             A model that implements sklearn.predict or sklearn.predict_proba
             or function that accepts a 2d ndarray.
@@ -67,7 +48,7 @@ class ModelAnalysis(object):
         :param categorical_features: The categorical feature names.
         :type categorical_features: list[str]
         :param train_labels: The class labels in the training dataset
-        :type train_labels: ndarray
+        :type train_labels: numpy.ndarray
         :param serializer: Picklable custom serializer with save and load
             methods defined for model that is not serializable. The save
             method returns a dictionary state and load method returns the
@@ -77,8 +58,10 @@ class ModelAnalysis(object):
             (for performance reasons)
         :type maximum_rows_for_test: int
         """
-        warnings.warn("ModelAnalysis in responsibleai package is deprecated."
-                      "Please use RAIInsights instead.")
+        warnings.warn(
+            "MODULE-DEPRECATION-WARNING: ModelAnalysis in responsibleai "
+            "package is deprecated. Please use RAIInsights instead.",
+            DeprecationWarning)
         self.rai_insights = RAIInsights(
             model,
             train,
@@ -89,12 +72,12 @@ class ModelAnalysis(object):
             classes=train_labels,
             serializer=serializer,
             maximum_rows_for_test=maximum_rows_for_test)
-        self.model = model
-        self.train = train
-        self.test = test
-        self.target_column = target_column
-        self.task_type = task_type
-        self.categorical_features = categorical_features
+        self.model = self.rai_insights.model
+        self.train = self.rai_insights.train
+        self.test = self.rai_insights.test
+        self.target_column = self.rai_insights.target_column
+        self.task_type = self.rai_insights.task_type
+        self.categorical_features = self.rai_insights.categorical_features
 
     @property
     def causal(self) -> CausalManager:
@@ -167,8 +150,8 @@ class ModelAnalysis(object):
         """Load the ModelAnalysis from the given path.
         :param path: The directory path to load the ModelAnalysis from.
         :type path: str
-        :return: The ModelAnlysis object after loading.
-        :rtype: ModelAnlysis
+        :return: The ModelAnalysis object after loading.
+        :rtype: ModelAnalysis
         """
         # create the ModelAnalysis without any properties using the __new__
         # function, similar to pickle
